@@ -29,18 +29,19 @@
 
 #include "debsig.h"
 
-int ds_debug_level = 1;
+int ds_debug_level = DS_LEV_INFO;
 
 void
 ds_printf(int level, const char *fmt, ...)
 {
     va_list ap;
 
-    if (level >= ds_debug_level) {
-	printf("debsig: ");
-	va_start(ap, fmt);
-	(void) vprintf(fmt, ap);
-	va_end(ap);
-	printf("\n");
-    }
+    if (ds_debug_level > level)
+      return;
+
+    printf("debsig: ");
+    va_start(ap, fmt);
+    (void) vprintf(fmt, ap);
+    va_end(ap);
+    printf("\n");
 }
